@@ -9,10 +9,10 @@ from edc_model import estimated_date_from_ago
 class TestEstimatedFromAgo(TestCase):
     def test_years_ago(self):
         cleaned_data = {
-            "report_datetime": datetime(2000, 5, 1).astimezone(ZoneInfo("UTC")),
+            "report_datetime": datetime(2000, 5, 1, tzinfo=ZoneInfo("UTC")),
             "ago_field": "5y",
         }
-        expected_date = (datetime(1995, 5, 1).astimezone(ZoneInfo("UTC"))).date()
+        expected_date = (datetime(1995, 5, 1, tzinfo=ZoneInfo("UTC"))).date()
 
         self.assertEqual(
             expected_date,
@@ -21,10 +21,10 @@ class TestEstimatedFromAgo(TestCase):
 
     def test_years_days_ago(self):
         cleaned_data = {
-            "report_datetime": datetime(2000, 5, 10).astimezone(ZoneInfo("UTC")),
+            "report_datetime": datetime(2000, 5, 10, tzinfo=ZoneInfo("UTC")),
             "ago_field": "5y3m",
         }
-        expected_date = (datetime(1995, 2, 10).astimezone(ZoneInfo("UTC"))).date()
+        expected_date = (datetime(1995, 2, 10, tzinfo=ZoneInfo("UTC"))).date()
 
         self.assertEqual(
             expected_date,
@@ -32,10 +32,10 @@ class TestEstimatedFromAgo(TestCase):
         )
 
         cleaned_data = {
-            "report_datetime": datetime(2000, 5, 31).astimezone(ZoneInfo("UTC")),
+            "report_datetime": datetime(2000, 5, 31, tzinfo=ZoneInfo("UTC")),
             "ago_field": "5y3m",
         }
-        expected_date = (datetime(1995, 2, 28).astimezone(ZoneInfo("UTC"))).date()
+        expected_date = (datetime(1995, 2, 28, tzinfo=ZoneInfo("UTC"))).date()
 
         self.assertEqual(
             expected_date,
@@ -44,10 +44,10 @@ class TestEstimatedFromAgo(TestCase):
 
         for i in range(4, 9):
             cleaned_data = {
-                "report_datetime": datetime(2000, i, 10).astimezone(ZoneInfo("UTC")),
+                "report_datetime": datetime(2000, i, 10, tzinfo=ZoneInfo("UTC")),
                 "ago_field": "5y3m",
             }
-            expected_date = (datetime(1995, i - 3, 10).astimezone(ZoneInfo("UTC"))).date()
+            expected_date = (datetime(1995, i - 3, 10, tzinfo=ZoneInfo("UTC"))).date()
 
             self.assertEqual(
                 expected_date,
@@ -56,10 +56,10 @@ class TestEstimatedFromAgo(TestCase):
 
         for i in range(1, 3):
             cleaned_data = {
-                "report_datetime": datetime(2000, i + 3, 10).astimezone(ZoneInfo("UTC")),
+                "report_datetime": datetime(2000, i + 3, 10, tzinfo=ZoneInfo("UTC")),
                 "ago_field": "5y3m",
             }
-            expected_date = (datetime(1995, i, 10).astimezone(ZoneInfo("UTC"))).date()
+            expected_date = (datetime(1995, i, 10, tzinfo=ZoneInfo("UTC"))).date()
 
             self.assertEqual(
                 expected_date,
@@ -68,7 +68,7 @@ class TestEstimatedFromAgo(TestCase):
 
     def test_with_years_and_days_raises(self):
         cleaned_data = {
-            "report_datetime": datetime(2000, 5, 10).astimezone(ZoneInfo("UTC")),
+            "report_datetime": datetime(2000, 5, 10, tzinfo=ZoneInfo("UTC")),
             "ago_field": "5y3d",
         }
 
@@ -81,10 +81,10 @@ class TestEstimatedFromAgo(TestCase):
 
     def test_with_days_ago(self):
         cleaned_data = {
-            "report_datetime": datetime(2000, 5, 10).astimezone(ZoneInfo("UTC")),
+            "report_datetime": datetime(2000, 5, 10, tzinfo=ZoneInfo("UTC")),
             "ago_field": "3d",
         }
-        expected_date = (datetime(2000, 5, 7).astimezone(ZoneInfo("UTC"))).date()
+        expected_date = (datetime(2000, 5, 7, tzinfo=ZoneInfo("UTC"))).date()
 
         self.assertEqual(
             expected_date,
